# Tan-chan

A utility library which extends Tanjun.

# Installation

You can install Tan-chan from PyPI using the following command in any Python 3.11 or above environment.

```
python -m pip install -U tanchan
```

The commands provided in `tanchan.components` require the 3rd party library Hikari-Yuyo to work.
The feature flag `tanchan[yuyo]` should be used to ensure that a compatible version of Yuyo is
installed (i.e. `pip install -U tanchan[yuyo]`).

# Quick Usage

For usage see the [documentation](https://tanchan.cursed.solutions/) and the
[usage guide](https://tanchan.cursed.solutions/usage/).

# Support

[Hikari's support guild](https://discord.gg/hikari) provides for support for Tan-chan.

# Contributing

Before contributing you should read through the
[contributing guidelines](https://github.com/FasterSpeeding/Tan-chan/blob/master/CONTRIBUTING.md) and
the [code of conduct](https://github.com/FasterSpeeding/Tan-chan/blob/master/CODE_OF_CONDUCT.md).
